==> funcoeszz_18.3.orig.tar.gz: funcoeszz-18.3/testador/zzpais.sh <==
$ zzpais -i unidos
País                                       Capital
------------------------------------------ ----------------------------------
Emirados Árabes Unidos                     Abu Dabi
Idioma(s): Árabe

Estados Unidos da América                  Washington, D.C.
Idioma(s): Inglês, Espanhol, Francês, Línguas indígenas, Havaiano

Ilhas Virgens dos Estados Unidos           Charlotte Amalie
Idioma(s): Inglês

$

$ zzpais ^Z
País                                       Capital
------------------------------------------ ----------------------------------
Zâmbia                                     Lusaca
Zimbábue                                   Harare
$

$ zzpais República
País                                       Capital
------------------------------------------ ----------------------------------
República Centro-Africana                  Bangui
República Checa                            Praga
República da China, ou Taiwan              Taipé
República Popular da China                 Pequim
República Turca de Chipre do Norte         Nicósia
República do Congo                         Brazavile
República Democrática do Congo             Quinxasa
República Dominicana                       São Domingos
República Árabe Saariana Democrática       El Aiune
$

$ zzpais l$
País                                       Capital
------------------------------------------ ----------------------------------
África do Sul                              Pretória, Cidade do Cabo, Bloemfontein
Brasil                                     Brasília
Guiné Equatorial                           Malabo
Israel                                     Jerusalém
Ilhas Marechal                             Majuro
Nepal                                      Catmandu
Ossétia do Sul                             Tskhinval
Portugal                                   Lisboa
Senegal                                    Dacar
Sudão do Sul                               Juba
$

$ zzpais -i ^J
País                                       Capital
------------------------------------------ ----------------------------------
Jamaica                                    Kingston
Idioma(s): Inglês

Japão                                      Tóquio
Idioma(s): Japonês

Jérsia                                     Saint Helier
Idioma(s): Inglês, Francês, Jersês

Jibuti ou Djibuti                          Jibuti
Idioma(s): Árabe, Francês

Jordânia                                   Amã
Idioma(s): Árabe

$

$ zzpais -o ^U
País     : Ukraїna, Україна
Capital  : Kyїv, Київ

País     : Uganda
Capital  : Kampala

País     : Uruguay
Capital  : Montevideo

País     : O'zbekiston
Capital  : Toshkent

$

==> funcoeszz_21.1.orig.tar.gz: funcoeszz-21.1/testador/zzpais.sh <==
$ zzpais -i unidos
País                                       Capital
------------------------------------------ ----------------------------------
Emirados Árabes Unidos                     Abu Dabi
Idioma(s): Árabe

Estados Unidos da América                  Washington, D.C.
Idioma(s): Inglês, Espanhol, Francês, Línguas indígenas, Havaiano

Ilhas Virgens dos Estados Unidos           Charlotte Amalie
Idioma(s): Inglês

$

$ zzpais ^Z
País                                       Capital
------------------------------------------ ----------------------------------
Zâmbia                                     Lusaca
Zimbábue                                   Harare
$

$ zzpais República
País                                       Capital
------------------------------------------ ----------------------------------
República Centro-Africana                  Bangui
República da Chinaou Taiwan, área autónoma Taipé
República Popular da China                 Pequim
República Turca de Chipre do Norte         Nicósia
República do Congo                         Brazavile
República Democrática do Congo             Quinxasa
República Dominicana                       São Domingos
República Árabe Saariana Democrática       El Aiune
República Tcheca ou Tchéquia ver em Chéquia.
$

$ zzpais l$
País                                       Capital
------------------------------------------ ----------------------------------
África do Sul                              Pretória, Cidade do Cabo, Bloemfontein
Brasil                                     Brasília
Guiné Equatorial                           Malabo
Israel                                     Jerusalém
Ilhas Marshall                             Majuro
Nepal                                      Catmandu
Ossétia do Sul                             Tskhinval
Portugal                                   Lisboa
Senegal                                    Dacar
Sudão do Sul                               Juba
$

$ zzpais -i ^J
País                                       Capital
------------------------------------------ ----------------------------------
Jamaica                                    Kingston
Idioma(s): Inglês

Japão                                      Tóquio
Idioma(s): Japonês

Jérsia                                     Saint Helier
Idioma(s): Inglês, Francês, Jersês

Jibuti ou Djibuti                          Jibuti
Idioma(s): Árabe, Francês

Jordânia                                   Amã
Idioma(s): Árabe

$

$ zzpais -o ^U
País     : Ukraїna, Україна
Capital  : Kyїv, Київ

País     : Uganda
Capital  : Kampala

País     : Uruguay
Capital  : Montevideo

País     : O'zbekiston
Capital  : Toshkent

$
